==> hermes-2.5.1.57.tar.gz: hermes-2.5.1.57/lib/hermes/rex_client/configuration.rb <==
require 'yaml'
module Hermes
  class RexClient::Configuration

    attr_accessor :auth_url
    attr_accessor :base_url
    attr_accessor :ed_entity
    attr_accessor :ed_lessor
    attr_accessor :ed_contact
    attr_accessor :client_id
    attr_accessor :client_secret
    attr_accessor :username
    attr_accessor :password
    attr_accessor :logger

    def logger=(value)
      @logger=case value
                when String
                  case value.downcase
                    when 'stdout'
                      Logger.new(STDOUT)
                    when 'stderr'
                      Logger.new(STDERR)
                    else
                      nil
                  end
                else
                  value
              end
    end

    def proxy
      RestClient.proxy
    end

    def proxy=(value)
      RestClient.proxy=value
    end

    def initialize(attrs={})
      self.auth_url                 = attrs.fetch(:auth_url, "https://rec.client.almerys.com/auth/realms/ALS/protocol/openid-connect/token")
      self.base_url                 = attrs.fetch(:base_url, "https://idrex-int.be-idys.com/id-rex-front-ws/context/264604c6-91f1-4473-8054-0f39bd63243f")
      self.ed_entity                = attrs.fetch(:ed_entity, "a0c7c1dc-435a-47c8-a8ff-0ccc4396588b")
      self.ed_lessor                = attrs.fetch(:ed_lessor, "54ea311b-c70e-4844-9a3e-585617d202c8")
      self.ed_contact               = attrs.fetch(:ed_contact, "ee923a25-31d8-4704-add7-75b4f1d60864")
      self.client_id                = attrs.fetch(:client_id, "id-rex_back")
      self.client_secret            = attrs.fetch(:client_secret, "6f593606-2306-4617-82b4-d0061a0f2d04")
      self.username                 = attrs.fetch(:username, "idrex_test_user_user_ro")
      self.password                 = attrs.fetch(:password, "Almerys*2000")
      self.proxy                    = attrs.fetch(:proxy, nil)
      self.logger                   = attrs.fetch(:logger, nil)

    end

    def self.from_yaml(path, env=nil)
      attrs = YAML.load_file(path)
      attrs = attrs[env] if env
      sym_attrs=attrs.each_with_object({}) {|(k, v), memo| memo[k.to_sym] = v}
      self.new(sym_attrs)
    end

  end
end

==> hermes-6.0.2.45.tar.gz: hermes-6.0.2.45/lib/hermes/rex_client/configuration.rb <==
require 'yaml'
module Hermes
  class RexClient::Configuration

    attr_accessor :auth_url
    attr_accessor :base_url
    attr_accessor :ed_entity
    attr_accessor :ed_lessor
    attr_accessor :ed_contact
    attr_accessor :client_id
    attr_accessor :client_secret
    attr_accessor :username
    attr_accessor :password
    attr_accessor :logger

    def logger=(value)
      @logger=case value
                when String
                  case value.downcase
                    when 'stdout'
                      Logger.new(STDOUT)
                    when 'stderr'
                      Logger.new(STDERR)
                    else
                      nil
                  end
                else
                  value
              end
    end

    def proxy
      RestClient.proxy
    end

    def proxy=(value)
      RestClient.proxy=value
    end

    def initialize(attrs={})
      self.auth_url                 = attrs.fetch(:auth_url, "https://rec.client.almerys.com/auth/realms/ALS/protocol/openid-connect/token")
      self.base_url                 = attrs.fetch(:base_url, "https://idrex-int.be-idys.com/id-rex-front-ws/context/1bf39a51-d57b-43fe-ad50-d426b9533b22")
      self.ed_entity                = attrs.fetch(:ed_entity, "804d1ddb-b508-40fa-8b00-27be5aba1bce")
      self.ed_lessor                = attrs.fetch(:ed_lessor, "64467464-8890-4429-94fa-e0ec34134dc5")
      self.ed_contact               = attrs.fetch(:ed_contact, "864e35c1-862a-4e8e-8f13-deab5ccdbe73")
      self.client_id                = attrs.fetch(:client_id, "id-rex_back")
      self.client_secret            = attrs.fetch(:client_secret, "6f593606-2306-4617-82b4-d0061a0f2d04")
      self.username                 = attrs.fetch(:username, "idrex_test_user_user_rw")
      self.password                 = attrs.fetch(:password, "beysALSREX2024")
      self.proxy                    = attrs.fetch(:proxy, nil)
      self.logger                   = attrs.fetch(:logger, nil)

    end

    def self.from_yaml(path, env=nil)
      attrs = YAML.load_file(path)
      attrs = attrs[env] if env
      sym_attrs=attrs.each_with_object({}) {|(k, v), memo| memo[k.to_sym] = v}
      self.new(sym_attrs)
    end

  end
end
